@@ -2,7 +2,7 @@ module OrdinaryDiffEqExplicitRK
 
 import OrdinaryDiffEqCore: alg_order, alg_adaptive_order, alg_stability_size,
                            OrdinaryDiffEqAdaptiveAlgorithm,
-                           @cache, alg_cache, OrdinaryDiffEqConstantCache, @unpack,
+                           @cache, alg_cache, OrdinaryDiffEqConstantCache,
                            unwrap_alg,
                            OrdinaryDiffEqMutableCache, initialize!, perform_step!, isfsal,
                            CompositeAlgorithm, calculate_residuals!, calculate_residuals,
